//@flow
/**
 * @author Sven Koelpin
 */

import React, { PureComponent } from 'react';
import type { Chat } from '../domain/Entities';
import { ChatWindow } from './ChatWindow';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import * as ChatActions from './ChatActions';
import type { StoreState } from '../store/Store';

type ReducerProps = {
    chats: Array<Chat>;
}

type Actions = {
    markChatAsRead: typeof ChatActions.markChatAsRead;
    subscribeToChatMessages: typeof ChatActions.subscribeToChatMessages;
    unsubscribeChatMessages: typeof ChatActions.unsubscribeChatMessages;
}

type Props = ReducerProps & Actions;

class ChatArea extends PureComponent<void, Props, void> {
    props: Props;

    componentDidMount() {
        this.props.subscribeToChatMessages();
    }

    componentWillUnmount() {
        this.props.unsubscribeChatMessages();
    }


    render() {
        const {chats, markChatAsRead} = this.props;
        return (
            <div className='chatArea'>
                {chats.map(chat => <ChatWindow key={chat.id} chat={chat} markAsRead={markChatAsRead}/>)}
            </div>
        );
    }
}


export default connect(
    (state: StoreState): ReducerProps => {
        const chatReducer = state.ChatReducer;
        const userReducer = state.UserReducer;
        return {
            chats: chatReducer.map(chat => ({
                id: chat.id,
                user: userReducer[chat.id],
                unread: chat.unread,
                messages: chat.messages
            }))
        }
    },
    dispatch => bindActionCreators(ChatActions, dispatch)
)(ChatArea);

