//@flow
/**
 * @author Sven Koelpin
 */
import React, { PureComponent } from 'react';
import style from './header.css';
import { connect } from 'react-redux';
import type { StoreState } from '../store/Store';

type Props = {|
    unreadChats: number;
    lang: ?string;
    hasUnreadChats: boolean;
|}

class Header extends PureComponent<void, Props, void> {
    props: Props;

    render() {
        const {unreadChats, lang, hasUnreadChats} = this.props;
        return (
            <header className={style.header}>
                <h1>Sven's book</h1>
                <div className={style.lang}>
                    <select defaultValue={lang}>
                        <option>{lang}</option>
                        <option>de</option>
                    </select>
                </div>
                {<div className={`${style.messages} ${hasUnreadChats ? style.unread : ''}`}>{hasUnreadChats && unreadChats}</div>}
            </header>
        );
    }
}


const mapStateToProps = (state: StoreState) => {
    const chatReducer = state.ChatReducer;
    const AppReducer = state.AppReducer;
    const numUnread = chatReducer.filter(chat => chat.unread).length;
    return {
        unreadChats: numUnread,
        hasUnreadChats: numUnread > 0,
        lang: AppReducer.lang
    }
};
export default connect(mapStateToProps)(Header);
