//@flow
/**
 * @author Sven Koelpin
 */
import React, { PureComponent } from 'react';
import style from './userList.css';
import { User } from '../domain/Entities';
import { connect } from 'react-redux';
import type { StoreState } from '../store/Store';
import * as UserActions from './UserActions';
import { bindActionCreators } from 'redux';

type Props = {|
    users: Array<User>;
|}

type Actions = {|
    fetchUsers: typeof UserActions.fetchUsers;
    subscribeToUserEvents: typeof UserActions.subscribeToUserEvents;
    unsubscribeUserEvents: typeof UserActions.unsubscribeUserEvents;
|}

class UserList extends PureComponent<void, Props & Actions, void> {
    props: Props & Actions;


    componentDidMount() {
        this.props.fetchUsers();
        this.props.subscribeToUserEvents();
    }

    componentWillUnmount() {
        this.props.unsubscribeUserEvents();
    }


    render() {
        const {users} = this.props;
        return (
            <ul className={style.userList}>
                {users.map(user => <li key={user.id}>{user.online ? <span className={style.online}/> : <span className={style.offline}/>} {user.name}</li>)}
            </ul>
        );
    }

}

const mapStateToProps = (state: StoreState): Props => ({
    users: Object.keys(state.UserReducer).map(userId => state.UserReducer[parseInt(userId, 10)])
});

const mapDispatchToProps = (dispatch: Function): Actions => bindActionCreators(UserActions, dispatch);


export default connect(mapStateToProps, mapDispatchToProps)(UserList);